﻿using System;
using System.ComponentModel.DataAnnotations;
using System.Text;
using System.Collections.Generic;
using System.Linq;
using HorseRaceTracker.Domain.Core;
using HorseRaceTracker.Domain.Utilities;
using Microsoft.VisualStudio.TestTools.UnitTesting;

namespace TestProject.Entities
{
    [TestClass]
    public class GivenNoHorseExists
    {
        [TestMethod]
        public void WhenValidatingHorseWithNoName_EntityShouldBeMarkedInvalid()
        {
            var horse = new Horse() { BirthYear = 2010, BredIn = new Country(), Name = null, Trainer = new Trainer(), Sex = Gender.Male };
           
            List<ValidationResult> results;
            bool isValid = EntityValidator.TryValidate(horse, out results);

            Assert.IsFalse(isValid);
            Assert.IsNotNull(results);
            Assert.IsTrue(results.Count==1); //first properties are checked

        }

        [TestMethod]
        public void WhenValidatingHorseWithNoCountry_EntityShouldBeMarkedInvalid()
        {
            var horse = new Horse() { BirthYear = 2010, BredIn = null, Name = "e", Trainer = new Trainer() , Sex =  Gender.Male};

            List<ValidationResult> results;
            bool isValid = EntityValidator.TryValidate(horse, out results);

            Assert.IsFalse(isValid);
            Assert.IsNotNull(results);
            Assert.IsTrue(results.Count == 1);

        }

        [TestMethod]
        public void WhenValidatingHorseWithNoTrainer_EntityShouldBeMarkedInvalid()
        {
            var horse = new Horse() { BirthYear = 2010, BredIn = new Country(), Name = "e", Trainer = null, Sex = Gender.Male };

            List<ValidationResult> results;
            bool isValid = EntityValidator.TryValidate(horse, out results);

            Assert.IsFalse(isValid);
            Assert.IsNotNull(results);
            Assert.IsTrue(results.Count == 1);

        }

        [TestMethod]
        public void WhenValidatingUnderAgedHorse_EntityShouldBeMarkedInValid()
        {
            var horse = new Horse() { BirthYear = 2012, BredIn = new Country(), Name = "e", Trainer = new Trainer(), Sex =  Gender.Male};

            List<ValidationResult> results;
            bool isValid = EntityValidator.TryValidate(horse, out results);

            Assert.IsFalse(isValid);
            Assert.IsNotNull(results);
            Assert.IsTrue(results.Count == 1);

        }

        [TestMethod]
        public void WhenValidatingTooOldHorse_EntityShouldBeMarkedInValid()
        {
            var horse = new Horse() { BirthYear = 1996, BredIn = new Country(), Name = "e", Trainer = new Trainer(), Sex = Gender.Male };

            List<ValidationResult> results;
            bool isValid = EntityValidator.TryValidate(horse, out results);

            Assert.IsFalse(isValid);
            Assert.IsNotNull(results);
            Assert.IsTrue(results.Count == 1);

        }
    }
}
